<?php

/**
 * Instagram Spider
 * @author Karan Singh
 * @version 1.1.5
 * @description script to get instagram media by using Username and/or Tag.
 */
class InstagramSpider
{
    
    protected $instagram;
    
    public $messages;
    
    public function __construct()
    {
        $this->instagram = 'https://www.instagram.com/';
        $this->messages = array();
    }
    
    /**
     * takes username and return items list array
     *
     * @param string $username
     * @return array
     */
    function getUserItems($username = '')
    {
        $username = urlencode((string) $username); // non-english string support
        if (empty($username)) {
            $this->messages[] = 'Please provide a valid username';
            return;
        }
        
        $inURL = $this->instagram . $username . '/media/';
        $instaRes = $this->ig_spider($inURL);
        $instaRes = @json_decode($instaRes);
        
        $items = array();
        if (isset($instaRes->items)) {
            $instaRes = $instaRes->items;
            
            if (! empty($instaRes) && is_array($instaRes)) {
                foreach ($instaRes as $res) {
                    $items[] = array(
                        'img_standard' => $res->images->standard_resolution->url,
                        'img_low' => $res->images->low_resolution->url,
                        'img_thumb' => $res->images->thumbnail->url,
                        'likes' => $res->likes->count,
                        'comments' => $res->comments->count,
                        'caption' => isset($res->caption->text) ? htmlspecialchars($res->caption->text) : '',
                    );
                }
            }
        }
        return $items;
    }
    
    /**
     * takes #Tag name and return items list array
     *
     * @param string $tag
     * @return array
     */
    function getTagItems($tag = '')
    {
        $tag = urlencode((string) $tag);
        if (empty($tag)) {
            $this->messages[] = 'Please provide a valid # tag';
            return;
        }
        $inURL = $this->instagram . 'explore/tags/' . $tag . '/?__a=1';
        $instaRes = $this->ig_spider($inURL);
        $instaRes = json_decode($instaRes);
        $items = array();
        if (isset($instaRes->tag->media->nodes)) {
            $instaRes = $instaRes->tag->media->nodes;
            
            if (! empty($instaRes) && is_array($instaRes)) {
                foreach ($instaRes as $res) {
                    $items[] = array(
                        'img_standard' => $res->display_src,
                        'img_low' => $res->thumbnail_src,
                        'img_thumb' => str_replace('s640x640','s150x150',$res->thumbnail_src),
                        'likes' => $res->likes->count,
                        'comments' => $res->comments->count,
                        'caption' => isset($res->caption) ? htmlspecialchars($res->caption) : '',
                    );
                }
            }
        }
        
        return $items;
    }
    
    /**
     * takes URL string and return URL content
     *
     * @param string $url
     * @return string
     */
    protected function ig_spider($url = '')
    {
        if (empty($url) || (! filter_var($url, FILTER_VALIDATE_URL))) {
            $this->messages[] = 'Please provide a Valid URL';
            return;
        }
        $instaItems = '';
        if (function_exists('curl_version')) {
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 10);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            $contents = curl_exec($ch);
            if (curl_error($ch)) {
                $this->messages[] = 'error: ' . curl_error($ch);
            }
            curl_close($ch);
            $instaItems = $contents;
        } else {
            if (ini_get('allow_url_fopen')) {
                $instaItems = @file_get_contents($url);
            } else {
                $this->messages[] = 'Your server does\'t have enabled the required extensions/functions.';
            }
        }
        return $instaItems;
    }
    
    // return messages array
    public function getMessages()
    {
        return $this->messages;
    }
}

